@@ -84,13 +84,15 @@ def count_persons_in_json(file_path):
         return len(data.get('people', []))
     
 
-def indices_of_first_last_non_nan_chunks(series, min_chunk_size=10):
+def indices_of_first_last_non_nan_chunks(series, min_chunk_size=10, chunk_choice_method='largest'):
     '''
-    Find indices of the first and last chunks of at least min_chunk_size consecutive non-NaN values.
+    Find indices of the chunks of at least min_chunk_size consecutive non-NaN values.
 
     INPUT:
     - series: pandas Series to trim
-    - min_chunk_size: minimum size of consecutive non-NaN values to consider (default: 5)
+    - min_chunk_size: minimum size of consecutive non-NaN values to consider (default: 10)
+    - chunk_choice_method: 'largest' to return the largest chunk, 'all' to return everything between the first and last non-nan chunk, 
+                          'first' to return only the first one, 'last' to return only the last one
 
     OUTPUT:
     - tuple: (start_index, end_index) of the first and last valid chunks
@@ -116,9 +118,22 @@ def indices_of_first_last_non_nan_chunks(series, min_chunk_size=10):
     if not valid_runs:
         return(0,0)
     
-    # Get the start of the first valid run and the end of the last valid run
-    first_run_start = valid_runs[0][0] + series.index.start
-    last_run_end = valid_runs[-1][1] + series.index.start
+    if chunk_choice_method not in ['largest', 'all', 'first', 'last']:
+        chunk_choice_method = 'all'
+    if chunk_choice_method == 'largest':
+        # Choose the largest chunk
+        valid_runs.sort(key=lambda x: x[1] - x[0], reverse=True)
+        first_run_start, last_run_end = valid_runs[0]
+    elif chunk_choice_method == 'all':
+        # Get the start of the first valid run and the end of the last valid run
+        first_run_start = valid_runs[0][0]
+        last_run_end = valid_runs[-1][1]
+    elif chunk_choice_method == 'first':
+        # Get the start of the first valid run and the end of that run
+        first_run_start, last_run_end = valid_runs[0]
+    elif chunk_choice_method == 'last':
+        # Get the start of the last valid run and the end of that run
+        first_run_start, last_run_end = valid_runs[-1]
     
     # Return the trimmed series
     return first_run_start, last_run_end
@@ -656,6 +671,7 @@ def triangulate_all(config_dict):
     likelihood_threshold = config_dict.get('triangulation').get('likelihood_threshold_triangulation')
     interpolation_kind = config_dict.get('triangulation').get('interpolation')
     interp_gap_smaller_than = config_dict.get('triangulation').get('interp_if_gap_smaller_than')
+    sections_to_keep = config_dict.get('triangulation').get('sections_to_keep')
     fill_large_gaps_with = config_dict.get('triangulation').get('fill_large_gaps_with')
     show_interp_indices = config_dict.get('triangulation').get('show_interp_indices')
     undistort_points = config_dict.get('triangulation').get('undistort_points')
@@ -865,7 +881,7 @@ def triangulate_all(config_dict):
     # error_tot[0].to_csv(os.path.join(session_dir, 'error_tot.csv'), index=False, sep='\t')
 
     # Trim around good frames and remove persons with too few frames
-    f_range_trimmed = [indices_of_first_last_non_nan_chunks(err['mean'], interp_gap_smaller_than) for err in error_tot]
+    f_range_trimmed = [indices_of_first_last_non_nan_chunks(err['mean'], min_chunk_size=interp_gap_smaller_than, chunk_choice_method=sections_to_keep) for err in error_tot]
     # f_range_trimmed = [f_range]*nb_persons_to_detect
     deleted_person_id = [n for n, f_range in enumerate(f_range_trimmed) if len(range(*f_range))<4]
     Q_tot = [Q_tot[n] for n in range(len(Q_tot)) if n not in deleted_person_id]
@@ -876,7 +892,7 @@ def triangulate_all(config_dict):
     if nb_persons_to_detect == 0:
         raise Exception('No persons have been triangulated. Please check your calibration and your synchronization, or the triangulation parameters in Config.toml.')
 
-    logging.info("Trimming " + ", ".join([f"Participant {n} around frames {f_range_trimmed[n]}" for n in range(nb_persons_to_detect)])+".")
+    logging.info("Trimming " + ", ".join([f"Participant {n+1} around frames {f_range_trimmed[n]}" for n in range(nb_persons_to_detect)])+".")
     Q_tot = [Q_tot[n].loc[f_range_trimmed[n][0]:f_range_trimmed[n][1]-1] for n in range(nb_persons_to_detect)]
     error_tot = [error_tot[n].loc[f_range_trimmed[n][0]:f_range_trimmed[n][1]-1] for n in range(nb_persons_to_detect)]
     nb_cams_excluded_tot = [nb_cams_excluded_tot[n].loc[f_range_trimmed[n][0]:f_range_trimmed[n][1]-1] for n in range(nb_persons_to_detect)]
